# Bits'N'Picas - Spec

The source code of this directory is copied from [bitsnpicas - e1627fa7a8b40754aeff13a479305dd0a4df3bd](https://github.com/kreativekorp/bitsnpicas/tree/ee1627fa7a8b40754aeff13a479305dd0a4df3bd).

Only used to generate test fonts and serve as specifications.

Follow the original project [LICENSE](https://github.com/kreativekorp/bitsnpicas/blob/master/main/java/BitsNPicas/LICENSE).
